@@ -14,9 +14,12 @@ package websocket
 
 import (
 	"errors"
-	"github.com/eclipse/che-machine-exec/exec"
+	"github.com/eclipse-che/che-machine-exec/auth"
+	"github.com/eclipse-che/che-machine-exec/common/rest"
+	"github.com/eclipse-che/che-machine-exec/exec"
+	"github.com/gin-gonic/gin"
 	"github.com/gorilla/websocket"
-	"log"
+	"github.com/sirupsen/logrus"
 	"net/http"
 	"strconv"
 )
@@ -29,7 +32,21 @@ var (
 	}
 )
 
-func Attach(w http.ResponseWriter, r *http.Request, idParam string) error {
+func HandleAttach(c *gin.Context) {
+	if auth.IsEnabled() {
+		_, err := auth.Authenticate(c)
+		if err != nil {
+			rest.WriteErrorResponse(c, err)
+			return
+		}
+	}
+
+	if err := doAttach(c.Writer, c.Request, c.Param("id")); err != nil {
+		c.JSON(c.Writer.Status(), err.Error())
+	}
+}
+
+func doAttach(w http.ResponseWriter, r *http.Request, idParam string) error {
 	id, err := strconv.Atoi(idParam)
 	if err != nil {
 		return errors.New("failed to parse id")
@@ -37,12 +54,12 @@ func Attach(w http.ResponseWriter, r *http.Request, idParam string) error {
 
 	wsConn, err := upgrader.Upgrade(w, r, nil)
 	if err != nil {
-		log.Println("Unable to upgrade connection to ws-conn " + err.Error())
+		logrus.Errorln("Unable to upgrade connection to ws-conn " + err.Error())
 		return err
 	}
 
 	if err = exec.GetExecManager().Attach(id, wsConn); err != nil {
-		log.Println("Attach to exec", strconv.Itoa(id), " failed. Cause:  ", err.Error())
+		logrus.Errorln("Attach to exec", strconv.Itoa(id), " failed. Cause:  ", err.Error())
 		return err
 	}
 
